@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,21 +14,20 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides debug utilities for Orca.  Debugging is managed by a debug
 level, which is held in the debugLevel field.  All other methods take
 a debug level, which is compared to the current debug level to
 determine if the content should be output."""
 
-__id__        = "$Id: debug.py 3189 2007-10-26 15:10:12Z wwalker $"
-__version__   = "$Revision: 3189 $"
-__date__      = "$Date: 2007-10-26 11:10:12 -0400 (Fri, 26 Oct 2007) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: debug.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import sys
 import traceback
 import pyatspi
 
@@ -145,17 +144,9 @@ def println(level, text = ""):
     - text: the text to print (default is a blank line)
     """
 
-    # Check to see if debugging is not enabled for the calling module.
-    #
-    frame = sys._getframe(1)
-    name = frame.f_globals["__name__"]
-    module = sys.modules[name]
-    if module.__dict__.has_key("_enableDebug") and not module._enableDebug:
-        return
-
     if level >= debugLevel:
         if debugFile:
-            debugFile.writelines([text,"\n"])
+            debugFile.writelines([text, "\n"])
         else:
             print text
 
