@@ -20,9 +20,9 @@
 """Provides support for defining keybindings and matching them to input
 events."""
 
-__id__        = "$Id: keybindings.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: keybindings.py 3971 2008-06-11 00:54:46Z joanied $"
+__version__   = "$Revision: 3971 $"
+__date__      = "$Date: 2008-06-10 20:54:46 -0400 (Tue, 10 Jun 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -51,7 +51,7 @@ def getAllKeysyms(keysym):
     that is mapped to the given keysym.  This allows us, for example,
     to determine that the key bound to KP_Insert is also bound to KP_0."""
 
-    if not _keysymsCache.has_key(keysym):
+    if keysym not in _keysymsCache:
         # The keysym itself is always part of the list.
         #
         _keysymsCache[keysym] = [keysym]
@@ -119,7 +119,7 @@ def getKeycode(keysym):
     if not keysym:
         return 0
 
-    if not _keycodeCache.has_key(keysym):
+    if keysym not in _keycodeCache:
         keymap = gtk.gdk.keymap_get_default()
 
         # Find the numerical value of the keysym
@@ -153,7 +153,7 @@ def getModifierNames(mods):
     """
 
     text = ""
-    if mods & (1 << settings.MODIFIER_ORCA):
+    if mods & settings.ORCA_MODIFIER_MASK:
         text += _("Orca") + "+"
     #if mods & (1 << pyatspi.MODIFIER_NUMLOCK):
     #    text += _("Num_Lock") + "+"
@@ -174,12 +174,12 @@ def getModifierNames(mods):
         text += _("Meta2") + "+"
     #if mods & (1 << pyatspi.MODIFIER_META):
     #    text += _("Meta") + "+"
-    if mods & (1 << pyatspi.MODIFIER_ALT):
+    if mods & settings.ALT_MODIFIER_MASK:
         # Translators: this is presented in a GUI to represent the
         # "left alt" modifier.
         #
         text += _("Alt_L") + "+"
-    if mods & (1 << pyatspi.MODIFIER_CONTROL):
+    if mods & settings.CTRL_MODIFIER_MASK:
         # Translators: this is presented in a GUI to represent the
         # "control" modifier.
         #
@@ -189,7 +189,7 @@ def getModifierNames(mods):
         # "caps lock" modifier.
         #
         text += _("Caps_Lock") + "+"
-    if mods & (1 << pyatspi.MODIFIER_SHIFT):
+    if mods & settings.SHIFT_MODIFIER_MASK:
         # Translators: this is presented in a GUI to represent the
         # "shift " modifier.
         #
