@@ -21,9 +21,9 @@
 """Provides methods that convert the role name of an Accessible
 object into localized strings for speech and braille."""
 
-__id__        = "$Id: rolenames.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: rolenames.py 4484 2009-01-31 15:40:03Z wwalker $"
+__version__   = "$Revision: 4484 $"
+__date__      = "$Date: 2009-01-31 10:40:03 -0500 (Sat, 31 Jan 2009) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -33,7 +33,7 @@ import settings
 import pyatspi
 
 from orca_i18n import _  # for gettext support
-from orca_i18n import Q_ # to provide qualified translatable strings
+from orca_i18n import C_ # to provide qualified translatable strings
 
 ########################################################################
 #                                                                      #
@@ -372,9 +372,7 @@ rolenames[ROLE_DIAL] = Rolename(
     # the translated word for "dial".  It is OK to use an
     # unabbreviated word as long as it is relatively short.
     #
-    # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-    #
-    Q_("shortbraille|dial"),
+    C_("shortbraille", "dial"),
     # Translators: long braille for the rolename of a dial.
     #
     _("Dial"),
@@ -473,9 +471,7 @@ rolenames[ROLE_FORM] = Rolename(
     # the translated word for "form".  It is OK to use an
     # unabbreviated word as long as it is relatively short.
     #
-    # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-    #
-    Q_("shortbraille|form"),
+    C_("shortbraille", "form"),
     # Translators: long braille for the rolename of a form.
     #
     _("Form"),
@@ -1183,6 +1179,28 @@ for sym in dir(pyatspi):
                 pyatspi_role = getattr(pyatspi, sym)
                 rolenames[pyatspi_role] = rolenames[key]
 
+def _adjustRole(obj, role):
+    """Adjust the role to what the role really is.
+    """
+
+    # Return fake "menu" role names.
+    #
+    if (role == pyatspi.ROLE_MENU_ITEM) \
+          and (obj.childCount > 0):
+        role = ROLE_MENU
+
+    # If this is an ARIA button with the "haspopup:true" attribute, then
+    # it's really a menu.
+    #
+    if role in [pyatspi.ROLE_PUSH_BUTTON, pyatspi.ROLE_MENU_ITEM]:
+        attributes = obj.getAttributes()
+        for attribute in attributes:
+            if attribute.startswith("haspopup:true"):
+                role = ROLE_MENU
+                break
+
+    return role
+
 def getSpeechForRoleName(obj, role=None):
     """Returns the localized name of the given Accessible object; the name is
     suitable to be spoken.  If a localized name cannot be discovered, this
@@ -1194,13 +1212,8 @@ def getSpeechForRoleName(obj, role=None):
     Returns a string containing the localized name of the object suitable
     to be spoken.
     """
-    role = role or obj.getRole()
 
-    # Return fake "menu" role names.
-    #[[[TODO: eitani - Discontinue ]]
-    if (role == pyatspi.ROLE_MENU_ITEM) \
-          and (obj.childCount > 0):
-        role = ROLE_MENU
+    role = _adjustRole(obj, role or obj.getRole())
 
     # If the enum is not in the dictionary, check by name.
     role_entry = \
@@ -1226,13 +1239,8 @@ def getShortBrailleForRoleName(obj, role=None):
     Returns a short string containing the localized name of the object
     suitable for a Braille display.
     """
-    role = role or obj.getRole()
 
-    # Return fake "menu" role names.
-    #[[[TODO: eitani - Discontinue ]]
-    if (role == pyatspi.ROLE_MENU_ITEM) \
-          and (obj.childCount > 0):
-        role = ROLE_MENU
+    role = _adjustRole(obj, role or obj.getRole())
 
     # If the enum is not in the dictionary, check by name.
     role_entry = \
@@ -1258,13 +1266,8 @@ def getLongBrailleForRoleName(obj, role=None):
     Returns a string containing the localized name of the object suitable for
     a Braille display.
     """
-    role = role or obj.getRole()
 
-    # Return fake "menu" role names.
-    #[[[TODO: eitani - Discontinue ]]
-    if (role == pyatspi.ROLE_MENU_ITEM) \
-          and (obj.childCount > 0):
-        role = ROLE_MENU
+    role = _adjustRole(obj, role or obj.getRole())
 
     # If the enum is not in the dictionary, check by name.
     role_entry = \
@@ -1279,9 +1282,6 @@ def getLongBrailleForRoleName(obj, role=None):
         else:
             return repr(role)
 
-
-
-
 def getBrailleForRoleName(obj, role=None):
     """Returns the localized name of the given Accessible object; the name is
     a string suitable for a Braille display.  If a localized name cannot
