@@ -27,9 +27,9 @@ The following script specific key sequences are supported:
   Insert-[1-9]  -  Speak and braille a previous chat room message.
 """
 
-__id__        = "$Id: script.py 3971 2008-06-11 00:54:46Z joanied $"
-__version__   = "$Revision: 3971 $"
-__date__      = "$Date: 2008-06-10 20:54:46 -0400 (Tue, 10 Jun 2008) $"
+__id__        = "$Id: script.py 4605 2009-02-26 13:08:55Z wwalker $"
+__version__   = "$Revision: 4605 $"
+__date__      = "$Date: 2009-02-26 08:08:55 -0500 (Thu, 26 Feb 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -687,6 +687,15 @@ class Script(default.Script):
         if self.isBuddyListEvent(event):
             return
 
+        # Handle non-chat text areas (e.g., adding a new account)
+        # the default way.
+        #
+        state = event.source.getState()
+        if state.contains(pyatspi.STATE_EDITABLE) \
+           and state.contains(pyatspi.STATE_SINGLE_LINE):
+            default.Script.onTextInserted(self, event)
+            return
+
         chatRoomTab = self.getChatRoomTab(event.source)
         if not chatRoomTab:
             default.Script.onTextInserted(self, event)
@@ -756,12 +765,15 @@ class Script(default.Script):
             # If the user doesn't want announcements for when their buddies
             # are typing (or have stopped typing), and this is such a message,
             # then just return. The only reliable way to identify such text
-            # is by the scale.  We also want to store the last message because
-            # msn seems to be sending a constant stream of "is typing" updates.
+            # is by the scale.  This attribute seems to have been removed by
+            # pidgin, so we'll also check the weight.  We also want to store
+            # the last message because msn seems to be sending a constant
+            # stream of "is typing" updates.
             #
             attr, start, end = \
                 self.getTextAttributes(event.source, event.detail1)
-            if float(attr.get('scale', '1')) < 1:
+            if float(attr.get('scale', '1')) < 1 \
+               or int(attr.get('weight', '400')) < 400:
                 if not script_settings.announceBuddyTyping or \
                        self.lastStatus == message:
                     return
