@@ -1,4 +1,4 @@
 from script import Script
 from speech_generator import SpeechGenerator
 from braille_generator import BrailleGenerator
-from constants import *
+import script_settings
