@@ -19,9 +19,9 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 4471 2009-01-28 17:52:43Z wwalker $"
-__version__   = "$Revision: 4471 $"
-__date__      = "$Date: 2009-01-28 12:52:43 -0500 (Wed, 28 Jan 2009) $"
+__id__        = "$Id: where_am_I.py 4611 2009-02-27 16:01:04Z wwalker $"
+__version__   = "$Revision: 4611 $"
+__date__      = "$Date: 2009-02-27 11:01:04 -0500 (Fri, 27 Feb 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -820,6 +820,23 @@ class WhereAmI:
         # Translators: this is the protocol of a link eg. http, mailto.
         #
         linkoutput = _('%s link') %link_uri_info[0]
+        text = self._script.getDisplayedText(obj)
+        if text:
+            linkoutput += " " + text
+        else:
+            # If there's no text for the link, expose part of the
+            # URI to the user.
+            #
+            basename = self._script.getLinkBasename(obj)
+            if basename:
+                linkoutput += " " + basename
+
+        # If the link has a child which is an image, we want
+        # to indicate that.
+        #
+        if obj.childCount and obj[0].getRole() == pyatspi.ROLE_IMAGE:
+            linkoutput += " " + self._getSpeechForRoleName(obj[0])
+
         domainoutput = ''
         sizeoutput = ''
       
